==> octave-forge_2001.11.02.orig.tar.gz: octave-forge-2001.11.02/main/image/jet.m <==
## Copyright (C) 1999,2000  Kai Habel
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

## -*- texinfo -*-
## @deftypefn {Function File} {} jet (@var{n})
## Create color colormap. 
## (dark blue through blue, cyan, green, yellow, red to dark red)
## The argument @var{n} should be a scalar.  If it
## is omitted, the length of the current colormap or 64 is assumed.
## @end deftypefn
## @seealso{colormap}

## Author:  Kai Habel <kai.habel@gmx.de>

function map = jet (number)

  global __current_color_map__

  if (nargin == 0)
    if (exist ("__current_color_map__"))
      number = rows (__current_color_map__);
    else
      number = 64;
    endif
  elseif (nargin == 1)
    if (! is_scalar (number))
      error ("jet: argument must be a scalar");
    endif
  else
    usage ("jet (number)");
  endif

  if (number == 1)
    map = [0, 0, 0.5];  
  elseif (number > 1)
    x = linspace(0, 1, number)';
    r = (x >= 3/8 & x < 5/8) .* (4 * x - 3/2)\
      + (x >= 5/8 & x < 7/8) + (x >= 7/8) .* (-4 * x + 9/2);
    g = (x >= 1/8 & x < 3/8) .* (4 * x - 1/2)\
      + (x >= 3/8 & x < 5/8) + (x >= 5/8 & x < 7/8) .* (-4 * x + 7/2);
    b = (x < 1/8) .* (4 * x + 1/2) + (x >= 1/8 & x < 3/8)\
      + (x >= 3/8 & x < 5/8) .* (-4 * x + 5/2);
    map = [r, g, b];
  else
    map = [];
  endif

endfunction

==> octave-forge-2006.07.09.tar.gz: octave-forge-2006.07.09/main/image/jet.m <==
## Copyright (C) 1999,2000  Kai Habel
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

## -*- texinfo -*-
## @deftypefn {Function File} {} jet (@var{n})
## Create color colormap. 
## (dark blue through blue, cyan, green, yellow, red to dark red)
## The argument @var{n} should be a scalar.  If it
## is omitted, the length of the current colormap or 64 is assumed.
## @end deftypefn
## @seealso{colormap}

## Author:  Kai Habel <kai.habel@gmx.de>

function map = jet (number)

  if (nargin == 0)
    number = rows (colormap);
  elseif (nargin == 1)
    if (! is_scalar (number))
      error ("jet: argument must be a scalar");
    endif
  else
    usage ("jet (number)");
  endif

  if (number == 1)
    map = [0, 0, 0.5];  
  elseif (number > 1)
    x = linspace(0, 1, number)';
    r = (x >= 3/8 & x < 5/8) .* (4 * x - 3/2)\
      + (x >= 5/8 & x < 7/8) + (x >= 7/8) .* (-4 * x + 9/2);
    g = (x >= 1/8 & x < 3/8) .* (4 * x - 1/2)\
      + (x >= 3/8 & x < 5/8) + (x >= 5/8 & x < 7/8) .* (-4 * x + 7/2);
    b = (x < 1/8) .* (4 * x + 1/2) + (x >= 1/8 & x < 3/8)\
      + (x >= 3/8 & x < 5/8) .* (-4 * x + 5/2);
    map = [r, g, b];
  else
    map = [];
  endif

endfunction
